#!/usr/bin/perl -w

#use lib './lib';

use XML::Malware;
use Data::Dumper;
use Digest::MD5 qw(md5 md5_hex);

my $h;
$h->{'company'} = 'wes co';
$h->{'author'} = 'wes';
$h->{'comment'} = 'test';
$h->{'timestamp'} = '2009-02-23T17:34:56';
$h->{'id'} = '';

my $md5 = '0371D9B2B239D96061F51F026C05597F';

push(@{$h->{'objects'}->{'file'}}, { id => "$md5",  md5 => $md5 });
push(@{$h->{'objects'}->{'classification'}}, { id => '', companyName => 'some company', type => 'dirty', classificationName => 'className'});

my $m = XML::Malware->new($h);

warn $m->out();

my $m2 = XML::Malware->new();
$m2->in($m->out());

warn Dumper($m->_hash());
